@@ -5,12 +5,11 @@ use strict;
 use warnings;
 
 # Modules.
-use Video::Delay::Array;
+use Video::Delay::Const;
 
 # Object.
-my $obj = Video::Delay::Array->new(
-        'array' => [1000, 2000],
-        'loop' => 1,
+my $obj = Video::Delay::Const->new(
+        'const' => 1000,
 );
 
 # Print delay.
@@ -20,5 +19,5 @@ print $obj->delay."\n";
 
 # Output:
 # 1000
-# 2000
+# 1000
 # 1000
\ No newline at end of file
